stm32-metapac

Crates

git

Versions

stm32u575rg

Flavors

Fgcmar

Struct Fgcmar 

#[repr(transparent)]
pub struct Fgcmar(pub u32);
DMA2D foreground CLUT memory address register

Tuple Fields

0: u32

Implementations



impl Fgcmar

pub const fn ma(&self) -> u32

Memory Address. Address of the data used for the CLUT address dedicated to the foreground image. This register can only be written when no transfer is ongoing. Once the CLUT transfer has started, this register is read-only. If the foreground CLUT format is 32-bit, the address must be 32-bit aligned.

pub const fn set_ma(&mut self, val: u32)

Memory Address. Address of the data used for the CLUT address dedicated to the foreground image. This register can only be written when no transfer is ongoing. Once the CLUT transfer has started, this register is read-only. If the foreground CLUT format is 32-bit, the address must be 32-bit aligned.